aboutsummaryrefslogtreecommitdiffstats
path: root/modules/web/default.nix
diff options
context:
space:
mode:
authorArpit Chakladar <arpitchakladar+git@gmail.com>2026-07-23 00:56:24 +0530
committerArpit Chakladar <arpitchakladar+git@gmail.com>2026-07-23 00:56:24 +0530
commit2ad7b06ced0ffa39d20e6be41466e5bd834ee956 (patch)
tree86bc522072c09c80098bff8854d2377137a6c39c /modules/web/default.nix
parenta61001ad8696f6d9a5ebe0f18a71d747941ec9d0 (diff)
downloadhome-manager-config-2ad7b06ced0ffa39d20e6be41466e5bd834ee956.tar.gz
home-manager-config-2ad7b06ced0ffa39d20e6be41466e5bd834ee956.zip
feat(w3m): add module with desktop entry + integrate into neomutt
- modules/web/w3m: enable/package options, desktop entry via kitty, assertion - modules/web/w3m: delegate to programs.w3m under the hood - modules/web/w3m: default package to programs.w3m.finalPackage - modules/desktop/xdg: add portal config with common.default = "*" - neomutt/nix: use lib.getExe' config.web.w3m.package for w3m refs - neomutt/assertions: add w3m dependency assertion - users/arpit: enable web.w3m
Diffstat (limited to 'modules/web/default.nix')
-rw-r--r--modules/web/default.nix3
1 files changed, 2 insertions, 1 deletions
diff --git a/modules/web/default.nix b/modules/web/default.nix
index a5c2ae6..436241a 100644
--- a/modules/web/default.nix
+++ b/modules/web/default.nix
@@ -1,8 +1,9 @@
# Web - Web browser and downloader modules (aria2, brave)
{ ... }:
{
imports = [
./aria2
./brave
+ ./w3m
];
}
@@ -1,8 +1,9 @@
-# Web - Web browser and downloader modules (aria2, brave)
+# Web - Web browser and downloader modules (aria2, brave, w3m)
{ ... }:
{